"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5712 import (
        AbstractAssemblyMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5713 import (
        AbstractShaftMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5714 import (
        AbstractShaftOrHousingMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5715 import (
        AbstractShaftToMountableComponentConnectionMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5716 import (
        AGMAGleasonConicalGearMeshMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5717 import (
        AGMAGleasonConicalGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5718 import (
        AGMAGleasonConicalGearSetMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5719 import (
        AnalysisTypes,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5720 import (
        AssemblyMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5721 import (
        BearingElementOrbitModel,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5722 import (
        BearingMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5723 import (
        BearingStiffnessModel,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5724 import (
        BeltConnectionMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5725 import (
        BeltDriveMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5726 import (
        BevelDifferentialGearMeshMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5727 import (
        BevelDifferentialGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5728 import (
        BevelDifferentialGearSetMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5729 import (
        BevelDifferentialPlanetGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5730 import (
        BevelDifferentialSunGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5731 import (
        BevelGearMeshMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5732 import (
        BevelGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5733 import (
        BevelGearSetMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5734 import (
        BoltedJointMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5735 import (
        BoltMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5736 import (
        ClutchConnectionMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5737 import (
        ClutchHalfMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5738 import (
        ClutchMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5739 import (
        ClutchSpringType,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5740 import (
        CoaxialConnectionMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5741 import (
        ComponentMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5742 import (
        ConceptCouplingConnectionMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5743 import (
        ConceptCouplingHalfMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5744 import (
        ConceptCouplingMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5745 import (
        ConceptGearMeshMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5746 import (
        ConceptGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5747 import (
        ConceptGearSetMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5748 import (
        ConicalGearMeshMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5749 import (
        ConicalGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5750 import (
        ConicalGearSetMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5751 import (
        ConnectionMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5752 import (
        ConnectorMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5753 import (
        CouplingConnectionMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5754 import (
        CouplingHalfMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5755 import (
        CouplingMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5756 import (
        CVTBeltConnectionMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5757 import (
        CVTMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5758 import (
        CVTPulleyMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5759 import (
        CycloidalAssemblyMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5760 import (
        CycloidalDiscCentralBearingConnectionMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5761 import (
        CycloidalDiscMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5762 import (
        CycloidalDiscPlanetaryBearingConnectionMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5763 import (
        CylindricalGearMeshMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5764 import (
        CylindricalGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5765 import (
        CylindricalGearSetMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5766 import (
        CylindricalPlanetGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5767 import (
        DatumMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5768 import (
        ExternalCADModelMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5769 import (
        FaceGearMeshMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5770 import (
        FaceGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5771 import (
        FaceGearSetMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5772 import (
        FEPartMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5773 import (
        FlexiblePinAssemblyMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5774 import (
        GearMeshMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5775 import (
        GearMeshStiffnessModel,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5776 import (
        GearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5777 import (
        GearSetMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5778 import (
        GuideDxfModelMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5779 import (
        HypoidGearMeshMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5780 import (
        HypoidGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5781 import (
        HypoidGearSetMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5782 import (
        InertiaAdjustedLoadCasePeriodMethod,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5783 import (
        InertiaAdjustedLoadCaseResultsToCreate,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5784 import (
        InputSignalFilterLevel,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5785 import (
        InputVelocityForRunUpProcessingType,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5786 import (
        InterMountableComponentConnectionMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5787 import (
        KlingelnbergCycloPalloidConicalGearMeshMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5788 import (
        KlingelnbergCycloPalloidConicalGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5789 import (
        KlingelnbergCycloPalloidConicalGearSetMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5790 import (
        KlingelnbergCycloPalloidHypoidGearMeshMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5791 import (
        KlingelnbergCycloPalloidHypoidGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5792 import (
        KlingelnbergCycloPalloidHypoidGearSetMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5793 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5794 import (
        KlingelnbergCycloPalloidSpiralBevelGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5795 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5796 import (
        MassDiscMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5797 import (
        MBDAnalysisDrawStyle,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5798 import (
        MBDAnalysisOptions,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5799 import (
        MBDRunUpAnalysisOptions,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5800 import (
        MeasurementComponentMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5801 import (
        MicrophoneArrayMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5802 import (
        MicrophoneMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5803 import (
        MountableComponentMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5804 import (
        MultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5805 import (
        OilSealMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5806 import (
        PartMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5807 import (
        PartToPartShearCouplingConnectionMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5808 import (
        PartToPartShearCouplingHalfMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5809 import (
        PartToPartShearCouplingMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5810 import (
        PlanetaryConnectionMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5811 import (
        PlanetaryGearSetMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5812 import (
        PlanetCarrierMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5813 import (
        PointLoadMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5814 import (
        PowerLoadMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5815 import (
        PulleyMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5816 import (
        RingPinsMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5817 import (
        RingPinsToDiscConnectionMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5818 import (
        RollingRingAssemblyMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5819 import (
        RollingRingConnectionMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5820 import (
        RollingRingMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5821 import (
        RootAssemblyMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5822 import (
        RunUpDrivingMode,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5823 import (
        ShaftAndHousingFlexibilityOption,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5824 import (
        ShaftHubConnectionMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5825 import (
        ShaftMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5826 import (
        ShaftToMountableComponentConnectionMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5827 import (
        ShapeOfInitialAccelerationPeriodForRunUp,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5828 import (
        SpecialisedAssemblyMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5829 import (
        SpiralBevelGearMeshMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5830 import (
        SpiralBevelGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5831 import (
        SpiralBevelGearSetMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5832 import (
        SplineDampingOptions,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5833 import (
        SpringDamperConnectionMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5834 import (
        SpringDamperHalfMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5835 import (
        SpringDamperMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5836 import (
        StraightBevelDiffGearMeshMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5837 import (
        StraightBevelDiffGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5838 import (
        StraightBevelDiffGearSetMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5839 import (
        StraightBevelGearMeshMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5840 import (
        StraightBevelGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5841 import (
        StraightBevelGearSetMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5842 import (
        StraightBevelPlanetGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5843 import (
        StraightBevelSunGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5844 import (
        SynchroniserHalfMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5845 import (
        SynchroniserMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5846 import (
        SynchroniserPartMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5847 import (
        SynchroniserSleeveMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5848 import (
        TorqueConverterConnectionMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5849 import (
        TorqueConverterLockupRule,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5850 import (
        TorqueConverterMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5851 import (
        TorqueConverterPumpMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5852 import (
        TorqueConverterStatus,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5853 import (
        TorqueConverterTurbineMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5854 import (
        UnbalancedMassMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5855 import (
        VirtualComponentMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5856 import (
        WheelSlipType,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5857 import (
        WormGearMeshMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5858 import (
        WormGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5859 import (
        WormGearSetMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5860 import (
        ZerolBevelGearMeshMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5861 import (
        ZerolBevelGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5862 import (
        ZerolBevelGearSetMultibodyDynamicsAnalysis,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.mbd_analyses._5712": [
            "AbstractAssemblyMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5713": [
            "AbstractShaftMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5714": [
            "AbstractShaftOrHousingMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5715": [
            "AbstractShaftToMountableComponentConnectionMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5716": [
            "AGMAGleasonConicalGearMeshMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5717": [
            "AGMAGleasonConicalGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5718": [
            "AGMAGleasonConicalGearSetMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5719": [
            "AnalysisTypes"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5720": [
            "AssemblyMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5721": [
            "BearingElementOrbitModel"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5722": [
            "BearingMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5723": [
            "BearingStiffnessModel"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5724": [
            "BeltConnectionMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5725": [
            "BeltDriveMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5726": [
            "BevelDifferentialGearMeshMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5727": [
            "BevelDifferentialGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5728": [
            "BevelDifferentialGearSetMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5729": [
            "BevelDifferentialPlanetGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5730": [
            "BevelDifferentialSunGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5731": [
            "BevelGearMeshMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5732": [
            "BevelGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5733": [
            "BevelGearSetMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5734": [
            "BoltedJointMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5735": [
            "BoltMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5736": [
            "ClutchConnectionMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5737": [
            "ClutchHalfMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5738": [
            "ClutchMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5739": [
            "ClutchSpringType"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5740": [
            "CoaxialConnectionMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5741": [
            "ComponentMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5742": [
            "ConceptCouplingConnectionMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5743": [
            "ConceptCouplingHalfMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5744": [
            "ConceptCouplingMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5745": [
            "ConceptGearMeshMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5746": [
            "ConceptGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5747": [
            "ConceptGearSetMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5748": [
            "ConicalGearMeshMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5749": [
            "ConicalGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5750": [
            "ConicalGearSetMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5751": [
            "ConnectionMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5752": [
            "ConnectorMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5753": [
            "CouplingConnectionMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5754": [
            "CouplingHalfMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5755": [
            "CouplingMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5756": [
            "CVTBeltConnectionMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5757": [
            "CVTMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5758": [
            "CVTPulleyMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5759": [
            "CycloidalAssemblyMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5760": [
            "CycloidalDiscCentralBearingConnectionMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5761": [
            "CycloidalDiscMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5762": [
            "CycloidalDiscPlanetaryBearingConnectionMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5763": [
            "CylindricalGearMeshMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5764": [
            "CylindricalGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5765": [
            "CylindricalGearSetMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5766": [
            "CylindricalPlanetGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5767": [
            "DatumMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5768": [
            "ExternalCADModelMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5769": [
            "FaceGearMeshMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5770": [
            "FaceGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5771": [
            "FaceGearSetMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5772": [
            "FEPartMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5773": [
            "FlexiblePinAssemblyMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5774": [
            "GearMeshMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5775": [
            "GearMeshStiffnessModel"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5776": [
            "GearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5777": [
            "GearSetMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5778": [
            "GuideDxfModelMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5779": [
            "HypoidGearMeshMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5780": [
            "HypoidGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5781": [
            "HypoidGearSetMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5782": [
            "InertiaAdjustedLoadCasePeriodMethod"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5783": [
            "InertiaAdjustedLoadCaseResultsToCreate"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5784": [
            "InputSignalFilterLevel"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5785": [
            "InputVelocityForRunUpProcessingType"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5786": [
            "InterMountableComponentConnectionMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5787": [
            "KlingelnbergCycloPalloidConicalGearMeshMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5788": [
            "KlingelnbergCycloPalloidConicalGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5789": [
            "KlingelnbergCycloPalloidConicalGearSetMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5790": [
            "KlingelnbergCycloPalloidHypoidGearMeshMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5791": [
            "KlingelnbergCycloPalloidHypoidGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5792": [
            "KlingelnbergCycloPalloidHypoidGearSetMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5793": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5794": [
            "KlingelnbergCycloPalloidSpiralBevelGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5795": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5796": [
            "MassDiscMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5797": [
            "MBDAnalysisDrawStyle"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5798": [
            "MBDAnalysisOptions"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5799": [
            "MBDRunUpAnalysisOptions"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5800": [
            "MeasurementComponentMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5801": [
            "MicrophoneArrayMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5802": [
            "MicrophoneMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5803": [
            "MountableComponentMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5804": [
            "MultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5805": [
            "OilSealMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5806": [
            "PartMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5807": [
            "PartToPartShearCouplingConnectionMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5808": [
            "PartToPartShearCouplingHalfMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5809": [
            "PartToPartShearCouplingMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5810": [
            "PlanetaryConnectionMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5811": [
            "PlanetaryGearSetMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5812": [
            "PlanetCarrierMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5813": [
            "PointLoadMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5814": [
            "PowerLoadMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5815": [
            "PulleyMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5816": [
            "RingPinsMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5817": [
            "RingPinsToDiscConnectionMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5818": [
            "RollingRingAssemblyMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5819": [
            "RollingRingConnectionMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5820": [
            "RollingRingMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5821": [
            "RootAssemblyMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5822": [
            "RunUpDrivingMode"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5823": [
            "ShaftAndHousingFlexibilityOption"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5824": [
            "ShaftHubConnectionMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5825": [
            "ShaftMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5826": [
            "ShaftToMountableComponentConnectionMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5827": [
            "ShapeOfInitialAccelerationPeriodForRunUp"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5828": [
            "SpecialisedAssemblyMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5829": [
            "SpiralBevelGearMeshMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5830": [
            "SpiralBevelGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5831": [
            "SpiralBevelGearSetMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5832": [
            "SplineDampingOptions"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5833": [
            "SpringDamperConnectionMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5834": [
            "SpringDamperHalfMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5835": [
            "SpringDamperMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5836": [
            "StraightBevelDiffGearMeshMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5837": [
            "StraightBevelDiffGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5838": [
            "StraightBevelDiffGearSetMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5839": [
            "StraightBevelGearMeshMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5840": [
            "StraightBevelGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5841": [
            "StraightBevelGearSetMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5842": [
            "StraightBevelPlanetGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5843": [
            "StraightBevelSunGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5844": [
            "SynchroniserHalfMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5845": [
            "SynchroniserMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5846": [
            "SynchroniserPartMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5847": [
            "SynchroniserSleeveMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5848": [
            "TorqueConverterConnectionMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5849": [
            "TorqueConverterLockupRule"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5850": [
            "TorqueConverterMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5851": [
            "TorqueConverterPumpMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5852": [
            "TorqueConverterStatus"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5853": [
            "TorqueConverterTurbineMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5854": [
            "UnbalancedMassMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5855": [
            "VirtualComponentMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5856": [
            "WheelSlipType"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5857": [
            "WormGearMeshMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5858": [
            "WormGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5859": [
            "WormGearSetMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5860": [
            "ZerolBevelGearMeshMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5861": [
            "ZerolBevelGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5862": [
            "ZerolBevelGearSetMultibodyDynamicsAnalysis"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyMultibodyDynamicsAnalysis",
    "AbstractShaftMultibodyDynamicsAnalysis",
    "AbstractShaftOrHousingMultibodyDynamicsAnalysis",
    "AbstractShaftToMountableComponentConnectionMultibodyDynamicsAnalysis",
    "AGMAGleasonConicalGearMeshMultibodyDynamicsAnalysis",
    "AGMAGleasonConicalGearMultibodyDynamicsAnalysis",
    "AGMAGleasonConicalGearSetMultibodyDynamicsAnalysis",
    "AnalysisTypes",
    "AssemblyMultibodyDynamicsAnalysis",
    "BearingElementOrbitModel",
    "BearingMultibodyDynamicsAnalysis",
    "BearingStiffnessModel",
    "BeltConnectionMultibodyDynamicsAnalysis",
    "BeltDriveMultibodyDynamicsAnalysis",
    "BevelDifferentialGearMeshMultibodyDynamicsAnalysis",
    "BevelDifferentialGearMultibodyDynamicsAnalysis",
    "BevelDifferentialGearSetMultibodyDynamicsAnalysis",
    "BevelDifferentialPlanetGearMultibodyDynamicsAnalysis",
    "BevelDifferentialSunGearMultibodyDynamicsAnalysis",
    "BevelGearMeshMultibodyDynamicsAnalysis",
    "BevelGearMultibodyDynamicsAnalysis",
    "BevelGearSetMultibodyDynamicsAnalysis",
    "BoltedJointMultibodyDynamicsAnalysis",
    "BoltMultibodyDynamicsAnalysis",
    "ClutchConnectionMultibodyDynamicsAnalysis",
    "ClutchHalfMultibodyDynamicsAnalysis",
    "ClutchMultibodyDynamicsAnalysis",
    "ClutchSpringType",
    "CoaxialConnectionMultibodyDynamicsAnalysis",
    "ComponentMultibodyDynamicsAnalysis",
    "ConceptCouplingConnectionMultibodyDynamicsAnalysis",
    "ConceptCouplingHalfMultibodyDynamicsAnalysis",
    "ConceptCouplingMultibodyDynamicsAnalysis",
    "ConceptGearMeshMultibodyDynamicsAnalysis",
    "ConceptGearMultibodyDynamicsAnalysis",
    "ConceptGearSetMultibodyDynamicsAnalysis",
    "ConicalGearMeshMultibodyDynamicsAnalysis",
    "ConicalGearMultibodyDynamicsAnalysis",
    "ConicalGearSetMultibodyDynamicsAnalysis",
    "ConnectionMultibodyDynamicsAnalysis",
    "ConnectorMultibodyDynamicsAnalysis",
    "CouplingConnectionMultibodyDynamicsAnalysis",
    "CouplingHalfMultibodyDynamicsAnalysis",
    "CouplingMultibodyDynamicsAnalysis",
    "CVTBeltConnectionMultibodyDynamicsAnalysis",
    "CVTMultibodyDynamicsAnalysis",
    "CVTPulleyMultibodyDynamicsAnalysis",
    "CycloidalAssemblyMultibodyDynamicsAnalysis",
    "CycloidalDiscCentralBearingConnectionMultibodyDynamicsAnalysis",
    "CycloidalDiscMultibodyDynamicsAnalysis",
    "CycloidalDiscPlanetaryBearingConnectionMultibodyDynamicsAnalysis",
    "CylindricalGearMeshMultibodyDynamicsAnalysis",
    "CylindricalGearMultibodyDynamicsAnalysis",
    "CylindricalGearSetMultibodyDynamicsAnalysis",
    "CylindricalPlanetGearMultibodyDynamicsAnalysis",
    "DatumMultibodyDynamicsAnalysis",
    "ExternalCADModelMultibodyDynamicsAnalysis",
    "FaceGearMeshMultibodyDynamicsAnalysis",
    "FaceGearMultibodyDynamicsAnalysis",
    "FaceGearSetMultibodyDynamicsAnalysis",
    "FEPartMultibodyDynamicsAnalysis",
    "FlexiblePinAssemblyMultibodyDynamicsAnalysis",
    "GearMeshMultibodyDynamicsAnalysis",
    "GearMeshStiffnessModel",
    "GearMultibodyDynamicsAnalysis",
    "GearSetMultibodyDynamicsAnalysis",
    "GuideDxfModelMultibodyDynamicsAnalysis",
    "HypoidGearMeshMultibodyDynamicsAnalysis",
    "HypoidGearMultibodyDynamicsAnalysis",
    "HypoidGearSetMultibodyDynamicsAnalysis",
    "InertiaAdjustedLoadCasePeriodMethod",
    "InertiaAdjustedLoadCaseResultsToCreate",
    "InputSignalFilterLevel",
    "InputVelocityForRunUpProcessingType",
    "InterMountableComponentConnectionMultibodyDynamicsAnalysis",
    "KlingelnbergCycloPalloidConicalGearMeshMultibodyDynamicsAnalysis",
    "KlingelnbergCycloPalloidConicalGearMultibodyDynamicsAnalysis",
    "KlingelnbergCycloPalloidConicalGearSetMultibodyDynamicsAnalysis",
    "KlingelnbergCycloPalloidHypoidGearMeshMultibodyDynamicsAnalysis",
    "KlingelnbergCycloPalloidHypoidGearMultibodyDynamicsAnalysis",
    "KlingelnbergCycloPalloidHypoidGearSetMultibodyDynamicsAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshMultibodyDynamicsAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearMultibodyDynamicsAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearSetMultibodyDynamicsAnalysis",
    "MassDiscMultibodyDynamicsAnalysis",
    "MBDAnalysisDrawStyle",
    "MBDAnalysisOptions",
    "MBDRunUpAnalysisOptions",
    "MeasurementComponentMultibodyDynamicsAnalysis",
    "MicrophoneArrayMultibodyDynamicsAnalysis",
    "MicrophoneMultibodyDynamicsAnalysis",
    "MountableComponentMultibodyDynamicsAnalysis",
    "MultibodyDynamicsAnalysis",
    "OilSealMultibodyDynamicsAnalysis",
    "PartMultibodyDynamicsAnalysis",
    "PartToPartShearCouplingConnectionMultibodyDynamicsAnalysis",
    "PartToPartShearCouplingHalfMultibodyDynamicsAnalysis",
    "PartToPartShearCouplingMultibodyDynamicsAnalysis",
    "PlanetaryConnectionMultibodyDynamicsAnalysis",
    "PlanetaryGearSetMultibodyDynamicsAnalysis",
    "PlanetCarrierMultibodyDynamicsAnalysis",
    "PointLoadMultibodyDynamicsAnalysis",
    "PowerLoadMultibodyDynamicsAnalysis",
    "PulleyMultibodyDynamicsAnalysis",
    "RingPinsMultibodyDynamicsAnalysis",
    "RingPinsToDiscConnectionMultibodyDynamicsAnalysis",
    "RollingRingAssemblyMultibodyDynamicsAnalysis",
    "RollingRingConnectionMultibodyDynamicsAnalysis",
    "RollingRingMultibodyDynamicsAnalysis",
    "RootAssemblyMultibodyDynamicsAnalysis",
    "RunUpDrivingMode",
    "ShaftAndHousingFlexibilityOption",
    "ShaftHubConnectionMultibodyDynamicsAnalysis",
    "ShaftMultibodyDynamicsAnalysis",
    "ShaftToMountableComponentConnectionMultibodyDynamicsAnalysis",
    "ShapeOfInitialAccelerationPeriodForRunUp",
    "SpecialisedAssemblyMultibodyDynamicsAnalysis",
    "SpiralBevelGearMeshMultibodyDynamicsAnalysis",
    "SpiralBevelGearMultibodyDynamicsAnalysis",
    "SpiralBevelGearSetMultibodyDynamicsAnalysis",
    "SplineDampingOptions",
    "SpringDamperConnectionMultibodyDynamicsAnalysis",
    "SpringDamperHalfMultibodyDynamicsAnalysis",
    "SpringDamperMultibodyDynamicsAnalysis",
    "StraightBevelDiffGearMeshMultibodyDynamicsAnalysis",
    "StraightBevelDiffGearMultibodyDynamicsAnalysis",
    "StraightBevelDiffGearSetMultibodyDynamicsAnalysis",
    "StraightBevelGearMeshMultibodyDynamicsAnalysis",
    "StraightBevelGearMultibodyDynamicsAnalysis",
    "StraightBevelGearSetMultibodyDynamicsAnalysis",
    "StraightBevelPlanetGearMultibodyDynamicsAnalysis",
    "StraightBevelSunGearMultibodyDynamicsAnalysis",
    "SynchroniserHalfMultibodyDynamicsAnalysis",
    "SynchroniserMultibodyDynamicsAnalysis",
    "SynchroniserPartMultibodyDynamicsAnalysis",
    "SynchroniserSleeveMultibodyDynamicsAnalysis",
    "TorqueConverterConnectionMultibodyDynamicsAnalysis",
    "TorqueConverterLockupRule",
    "TorqueConverterMultibodyDynamicsAnalysis",
    "TorqueConverterPumpMultibodyDynamicsAnalysis",
    "TorqueConverterStatus",
    "TorqueConverterTurbineMultibodyDynamicsAnalysis",
    "UnbalancedMassMultibodyDynamicsAnalysis",
    "VirtualComponentMultibodyDynamicsAnalysis",
    "WheelSlipType",
    "WormGearMeshMultibodyDynamicsAnalysis",
    "WormGearMultibodyDynamicsAnalysis",
    "WormGearSetMultibodyDynamicsAnalysis",
    "ZerolBevelGearMeshMultibodyDynamicsAnalysis",
    "ZerolBevelGearMultibodyDynamicsAnalysis",
    "ZerolBevelGearSetMultibodyDynamicsAnalysis",
)



"""Iso10300FinishingMethods"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal.python_net import python_net_import

_ISO_10300_FINISHING_METHODS = python_net_import(
    "SMT.MastaAPI.Gears.Rating.Iso10300", "Iso10300FinishingMethods"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="Iso10300FinishingMethods")
    CastSelf = TypeVar(
        "CastSelf", bound="Iso10300FinishingMethods._Cast_Iso10300FinishingMethods"
    )


__docformat__ = "restructuredtext en"
__all__ = ("Iso10300FinishingMethods",)


class Iso10300FinishingMethods(Enum):
    """Iso10300FinishingMethods

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls) -> "Type":
        return _ISO_10300_FINISHING_METHODS

    NONE = 0
    LAPPED = 1
    GROUND = 2
    HARD_CUT = 3


def __enum_setattr(self: "Self", attr: str, value: "Any") -> None:
    raise AttributeError("Cannot set the attributes of an Enum.") from None


def __enum_delattr(self: "Self", attr: str) -> None:
    raise AttributeError("Cannot delete the attributes of an Enum.") from None


Iso10300FinishingMethods.__setattr__ = __enum_setattr
Iso10300FinishingMethods.__delattr__ = __enum_delattr



"""DIN3990MeshSingleFlankRating"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.gears.rating.cylindrical.iso6336 import _625

_DIN3990_MESH_SINGLE_FLANK_RATING = python_net_import(
    "SMT.MastaAPI.Gears.Rating.Cylindrical.DIN3990", "DIN3990MeshSingleFlankRating"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.gears.rating import _479
    from mastapy._private.gears.rating.cylindrical import _580, _594, _595
    from mastapy._private.gears.rating.cylindrical.iso6336 import _631, _633

    Self = TypeVar("Self", bound="DIN3990MeshSingleFlankRating")
    CastSelf = TypeVar(
        "CastSelf",
        bound="DIN3990MeshSingleFlankRating._Cast_DIN3990MeshSingleFlankRating",
    )


__docformat__ = "restructuredtext en"
__all__ = ("DIN3990MeshSingleFlankRating",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_DIN3990MeshSingleFlankRating:
    """Special nested class for casting DIN3990MeshSingleFlankRating to subclasses."""

    __parent__: "DIN3990MeshSingleFlankRating"

    @property
    def iso63361996_mesh_single_flank_rating(
        self: "CastSelf",
    ) -> "_625.ISO63361996MeshSingleFlankRating":
        return self.__parent__._cast(_625.ISO63361996MeshSingleFlankRating)

    @property
    def iso6336_abstract_metal_mesh_single_flank_rating(
        self: "CastSelf",
    ) -> "_633.ISO6336AbstractMetalMeshSingleFlankRating":
        from mastapy._private.gears.rating.cylindrical.iso6336 import _633

        return self.__parent__._cast(_633.ISO6336AbstractMetalMeshSingleFlankRating)

    @property
    def iso6336_abstract_mesh_single_flank_rating(
        self: "CastSelf",
    ) -> "_631.ISO6336AbstractMeshSingleFlankRating":
        from mastapy._private.gears.rating.cylindrical.iso6336 import _631

        return self.__parent__._cast(_631.ISO6336AbstractMeshSingleFlankRating)

    @property
    def cylindrical_mesh_single_flank_rating(
        self: "CastSelf",
    ) -> "_580.CylindricalMeshSingleFlankRating":
        from mastapy._private.gears.rating.cylindrical import _580

        return self.__parent__._cast(_580.CylindricalMeshSingleFlankRating)

    @property
    def mesh_single_flank_rating(self: "CastSelf") -> "_479.MeshSingleFlankRating":
        from mastapy._private.gears.rating import _479

        return self.__parent__._cast(_479.MeshSingleFlankRating)

    @property
    def din3990_mesh_single_flank_rating(
        self: "CastSelf",
    ) -> "DIN3990MeshSingleFlankRating":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class DIN3990MeshSingleFlankRating(_625.ISO63361996MeshSingleFlankRating):
    """DIN3990MeshSingleFlankRating

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _DIN3990_MESH_SINGLE_FLANK_RATING

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def basic_mean_flash_temperature(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "BasicMeanFlashTemperature")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def estimated_bulk_temperature_flash(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "EstimatedBulkTemperatureFlash")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def estimated_bulk_temperature_integral(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "EstimatedBulkTemperatureIntegral")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def flash_factor_integral(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "FlashFactorIntegral")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def geometry_factor_at_maximum_flash_temperature(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "GeometryFactorAtMaximumFlashTemperature"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def integral_scuffing_temperature(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "IntegralScuffingTemperature")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def load_distribution_factor_at_maximum_flash_temperature(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "LoadDistributionFactorAtMaximumFlashTemperature"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def mean_coefficient_of_friction_integral_temperature_method(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "MeanCoefficientOfFrictionIntegralTemperatureMethod"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def mean_local_coefficient_of_friction_at_maximum_flash_temperature(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "MeanLocalCoefficientOfFrictionAtMaximumFlashTemperature"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def parameter_on_line_of_action_at_maximum_flash_temperature(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "ParameterOnLineOfActionAtMaximumFlashTemperature"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def rating_standard_name(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "RatingStandardName")

        if temp is None:
            return ""

        return temp

    @property
    @exception_bridge
    def resonance_ratio_in_the_main_resonance_range(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "ResonanceRatioInTheMainResonanceRange"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def scuffing_rating_method_flash_temperature_method(
        self: "Self",
    ) -> "_594.ScuffingFlashTemperatureRatingMethod":
        """mastapy.gears.rating.cylindrical.ScuffingFlashTemperatureRatingMethod

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "ScuffingRatingMethodFlashTemperatureMethod"
        )

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp,
            "SMT.MastaAPI.Gears.Rating.Cylindrical.ScuffingFlashTemperatureRatingMethod",
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.gears.rating.cylindrical._594",
            "ScuffingFlashTemperatureRatingMethod",
        )(value)

    @property
    @exception_bridge
    def scuffing_rating_method_integral_temperature_method(
        self: "Self",
    ) -> "_595.ScuffingIntegralTemperatureRatingMethod":
        """mastapy.gears.rating.cylindrical.ScuffingIntegralTemperatureRatingMethod

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "ScuffingRatingMethodIntegralTemperatureMethod"
        )

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp,
            "SMT.MastaAPI.Gears.Rating.Cylindrical.ScuffingIntegralTemperatureRatingMethod",
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.gears.rating.cylindrical._595",
            "ScuffingIntegralTemperatureRatingMethod",
        )(value)

    @property
    @exception_bridge
    def thermo_elastic_factor_at_maximum_flash_temperature(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "ThermoElasticFactorAtMaximumFlashTemperature"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def tip_relief_factor_integral(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "TipReliefFactorIntegral")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def transverse_unit_load(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "TransverseUnitLoad")

        if temp is None:
            return 0.0

        return temp

    @property
    def cast_to(self: "Self") -> "_Cast_DIN3990MeshSingleFlankRating":
        """Cast to another type.

        Returns:
            _Cast_DIN3990MeshSingleFlankRating
        """
        return _Cast_DIN3990MeshSingleFlankRating(self)



"""WormGrindingProcessGearShape"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private._internal import constructor, utility
from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new import (
    _820,
)

_WORM_GRINDING_PROCESS_GEAR_SHAPE = python_net_import(
    "SMT.MastaAPI.Gears.Manufacturing.Cylindrical.HobbingProcessSimulationNew",
    "WormGrindingProcessGearShape",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new import (
        _806,
    )
    from mastapy._private.utility_gui.charts import _2106

    Self = TypeVar("Self", bound="WormGrindingProcessGearShape")
    CastSelf = TypeVar(
        "CastSelf",
        bound="WormGrindingProcessGearShape._Cast_WormGrindingProcessGearShape",
    )


__docformat__ = "restructuredtext en"
__all__ = ("WormGrindingProcessGearShape",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_WormGrindingProcessGearShape:
    """Special nested class for casting WormGrindingProcessGearShape to subclasses."""

    __parent__: "WormGrindingProcessGearShape"

    @property
    def worm_grinding_process_calculation(
        self: "CastSelf",
    ) -> "_820.WormGrindingProcessCalculation":
        return self.__parent__._cast(_820.WormGrindingProcessCalculation)

    @property
    def process_calculation(self: "CastSelf") -> "_806.ProcessCalculation":
        from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new import (
            _806,
        )

        return self.__parent__._cast(_806.ProcessCalculation)

    @property
    def worm_grinding_process_gear_shape(
        self: "CastSelf",
    ) -> "WormGrindingProcessGearShape":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class WormGrindingProcessGearShape(_820.WormGrindingProcessCalculation):
    """WormGrindingProcessGearShape

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _WORM_GRINDING_PROCESS_GEAR_SHAPE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def gear_tooth_shape_chart(self: "Self") -> "_2106.TwoDChartDefinition":
        """mastapy.utility_gui.charts.TwoDChartDefinition

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "GearToothShapeChart")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def number_of_gear_shape_bands(self: "Self") -> "int":
        """int"""
        temp = pythonnet_property_get(self.wrapped, "NumberOfGearShapeBands")

        if temp is None:
            return 0

        return temp

    @number_of_gear_shape_bands.setter
    @exception_bridge
    @enforce_parameter_types
    def number_of_gear_shape_bands(self: "Self", value: "int") -> None:
        pythonnet_property_set(
            self.wrapped,
            "NumberOfGearShapeBands",
            int(value) if value is not None else 0,
        )

    @property
    @exception_bridge
    def result_z_plane(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "ResultZPlane")

        if temp is None:
            return 0.0

        return temp

    @result_z_plane.setter
    @exception_bridge
    @enforce_parameter_types
    def result_z_plane(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "ResultZPlane", float(value) if value is not None else 0.0
        )

    @property
    def cast_to(self: "Self") -> "_Cast_WormGrindingProcessGearShape":
        """Cast to another type.

        Returns:
            _Cast_WormGrindingProcessGearShape
        """
        return _Cast_WormGrindingProcessGearShape(self)



"""AbstractAssemblyModalAnalysis"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.system_model.analyses_and_results.modal_analyses import _4988

_ABSTRACT_ASSEMBLY_MODAL_ANALYSIS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalyses",
    "AbstractAssemblyModalAnalysis",
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results import _2944, _2946, _2950
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7943,
        _7946,
    )
    from mastapy._private.system_model.analyses_and_results.modal_analyses import (
        _4901,
        _4902,
        _4905,
        _4908,
        _4913,
        _4914,
        _4918,
        _4920,
        _4923,
        _4926,
        _4929,
        _4935,
        _4937,
        _4939,
        _4945,
        _4954,
        _4956,
        _4958,
        _4960,
        _4964,
        _4968,
        _4971,
        _4974,
        _4977,
        _4991,
        _4993,
        _5000,
        _5003,
        _5008,
        _5011,
        _5014,
        _5017,
        _5020,
        _5024,
        _5028,
        _5038,
        _5041,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections import (
        _2978,
    )
    from mastapy._private.system_model.part_model import _2704

    Self = TypeVar("Self", bound="AbstractAssemblyModalAnalysis")
    CastSelf = TypeVar(
        "CastSelf",
        bound="AbstractAssemblyModalAnalysis._Cast_AbstractAssemblyModalAnalysis",
    )


__docformat__ = "restructuredtext en"
__all__ = ("AbstractAssemblyModalAnalysis",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_AbstractAssemblyModalAnalysis:
    """Special nested class for casting AbstractAssemblyModalAnalysis to subclasses."""

    __parent__: "AbstractAssemblyModalAnalysis"

    @property
    def part_modal_analysis(self: "CastSelf") -> "_4988.PartModalAnalysis":
        return self.__parent__._cast(_4988.PartModalAnalysis)

    @property
    def part_static_load_analysis_case(
        self: "CastSelf",
    ) -> "_7946.PartStaticLoadAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7946,
        )

        return self.__parent__._cast(_7946.PartStaticLoadAnalysisCase)

    @property
    def part_analysis_case(self: "CastSelf") -> "_7943.PartAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7943,
        )

        return self.__parent__._cast(_7943.PartAnalysisCase)

    @property
    def part_analysis(self: "CastSelf") -> "_2950.PartAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2950

        return self.__parent__._cast(_2950.PartAnalysis)

    @property
    def design_entity_single_context_analysis(
        self: "CastSelf",
    ) -> "_2946.DesignEntitySingleContextAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2946

        return self.__parent__._cast(_2946.DesignEntitySingleContextAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2944.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2944

        return self.__parent__._cast(_2944.DesignEntityAnalysis)

    @property
    def agma_gleason_conical_gear_set_modal_analysis(
        self: "CastSelf",
    ) -> "_4901.AGMAGleasonConicalGearSetModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4901,
        )

        return self.__parent__._cast(_4901.AGMAGleasonConicalGearSetModalAnalysis)

    @property
    def assembly_modal_analysis(self: "CastSelf") -> "_4902.AssemblyModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4902,
        )

        return self.__parent__._cast(_4902.AssemblyModalAnalysis)

    @property
    def belt_drive_modal_analysis(self: "CastSelf") -> "_4905.BeltDriveModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4905,
        )

        return self.__parent__._cast(_4905.BeltDriveModalAnalysis)

    @property
    def bevel_differential_gear_set_modal_analysis(
        self: "CastSelf",
    ) -> "_4908.BevelDifferentialGearSetModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4908,
        )

        return self.__parent__._cast(_4908.BevelDifferentialGearSetModalAnalysis)

    @property
    def bevel_gear_set_modal_analysis(
        self: "CastSelf",
    ) -> "_4913.BevelGearSetModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4913,
        )

        return self.__parent__._cast(_4913.BevelGearSetModalAnalysis)

    @property
    def bolted_joint_modal_analysis(
        self: "CastSelf",
    ) -> "_4914.BoltedJointModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4914,
        )

        return self.__parent__._cast(_4914.BoltedJointModalAnalysis)

    @property
    def clutch_modal_analysis(self: "CastSelf") -> "_4918.ClutchModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4918,
        )

        return self.__parent__._cast(_4918.ClutchModalAnalysis)

    @property
    def concept_coupling_modal_analysis(
        self: "CastSelf",
    ) -> "_4923.ConceptCouplingModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4923,
        )

        return self.__parent__._cast(_4923.ConceptCouplingModalAnalysis)

    @property
    def concept_gear_set_modal_analysis(
        self: "CastSelf",
    ) -> "_4926.ConceptGearSetModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4926,
        )

        return self.__parent__._cast(_4926.ConceptGearSetModalAnalysis)

    @property
    def conical_gear_set_modal_analysis(
        self: "CastSelf",
    ) -> "_4929.ConicalGearSetModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4929,
        )

        return self.__parent__._cast(_4929.ConicalGearSetModalAnalysis)

    @property
    def coupling_modal_analysis(self: "CastSelf") -> "_4935.CouplingModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4935,
        )

        return self.__parent__._cast(_4935.CouplingModalAnalysis)

    @property
    def cvt_modal_analysis(self: "CastSelf") -> "_4937.CVTModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4937,
        )

        return self.__parent__._cast(_4937.CVTModalAnalysis)

    @property
    def cycloidal_assembly_modal_analysis(
        self: "CastSelf",
    ) -> "_4939.CycloidalAssemblyModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4939,
        )

        return self.__parent__._cast(_4939.CycloidalAssemblyModalAnalysis)

    @property
    def cylindrical_gear_set_modal_analysis(
        self: "CastSelf",
    ) -> "_4945.CylindricalGearSetModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4945,
        )

        return self.__parent__._cast(_4945.CylindricalGearSetModalAnalysis)

    @property
    def face_gear_set_modal_analysis(
        self: "CastSelf",
    ) -> "_4954.FaceGearSetModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4954,
        )

        return self.__parent__._cast(_4954.FaceGearSetModalAnalysis)

    @property
    def flexible_pin_assembly_modal_analysis(
        self: "CastSelf",
    ) -> "_4956.FlexiblePinAssemblyModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4956,
        )

        return self.__parent__._cast(_4956.FlexiblePinAssemblyModalAnalysis)

    @property
    def gear_set_modal_analysis(self: "CastSelf") -> "_4960.GearSetModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4960,
        )

        return self.__parent__._cast(_4960.GearSetModalAnalysis)

    @property
    def hypoid_gear_set_modal_analysis(
        self: "CastSelf",
    ) -> "_4964.HypoidGearSetModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4964,
        )

        return self.__parent__._cast(_4964.HypoidGearSetModalAnalysis)

    @property
    def klingelnberg_cyclo_palloid_conical_gear_set_modal_analysis(
        self: "CastSelf",
    ) -> "_4968.KlingelnbergCycloPalloidConicalGearSetModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4968,
        )

        return self.__parent__._cast(
            _4968.KlingelnbergCycloPalloidConicalGearSetModalAnalysis
        )

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_set_modal_analysis(
        self: "CastSelf",
    ) -> "_4971.KlingelnbergCycloPalloidHypoidGearSetModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4971,
        )

        return self.__parent__._cast(
            _4971.KlingelnbergCycloPalloidHypoidGearSetModalAnalysis
        )

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_set_modal_analysis(
        self: "CastSelf",
    ) -> "_4974.KlingelnbergCycloPalloidSpiralBevelGearSetModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4974,
        )

        return self.__parent__._cast(
            _4974.KlingelnbergCycloPalloidSpiralBevelGearSetModalAnalysis
        )

    @property
    def microphone_array_modal_analysis(
        self: "CastSelf",
    ) -> "_4977.MicrophoneArrayModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4977,
        )

        return self.__parent__._cast(_4977.MicrophoneArrayModalAnalysis)

    @property
    def part_to_part_shear_coupling_modal_analysis(
        self: "CastSelf",
    ) -> "_4991.PartToPartShearCouplingModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4991,
        )

        return self.__parent__._cast(_4991.PartToPartShearCouplingModalAnalysis)

    @property
    def planetary_gear_set_modal_analysis(
        self: "CastSelf",
    ) -> "_4993.PlanetaryGearSetModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _4993,
        )

        return self.__parent__._cast(_4993.PlanetaryGearSetModalAnalysis)

    @property
    def rolling_ring_assembly_modal_analysis(
        self: "CastSelf",
    ) -> "_5000.RollingRingAssemblyModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _5000,
        )

        return self.__parent__._cast(_5000.RollingRingAssemblyModalAnalysis)

    @property
    def root_assembly_modal_analysis(
        self: "CastSelf",
    ) -> "_5003.RootAssemblyModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _5003,
        )

        return self.__parent__._cast(_5003.RootAssemblyModalAnalysis)

    @property
    def specialised_assembly_modal_analysis(
        self: "CastSelf",
    ) -> "_5008.SpecialisedAssemblyModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _5008,
        )

        return self.__parent__._cast(_5008.SpecialisedAssemblyModalAnalysis)

    @property
    def spiral_bevel_gear_set_modal_analysis(
        self: "CastSelf",
    ) -> "_5011.SpiralBevelGearSetModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _5011,
        )

        return self.__parent__._cast(_5011.SpiralBevelGearSetModalAnalysis)

    @property
    def spring_damper_modal_analysis(
        self: "CastSelf",
    ) -> "_5014.SpringDamperModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _5014,
        )

        return self.__parent__._cast(_5014.SpringDamperModalAnalysis)

    @property
    def straight_bevel_diff_gear_set_modal_analysis(
        self: "CastSelf",
    ) -> "_5017.StraightBevelDiffGearSetModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _5017,
        )

        return self.__parent__._cast(_5017.StraightBevelDiffGearSetModalAnalysis)

    @property
    def straight_bevel_gear_set_modal_analysis(
        self: "CastSelf",
    ) -> "_5020.StraightBevelGearSetModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _5020,
        )

        return self.__parent__._cast(_5020.StraightBevelGearSetModalAnalysis)

    @property
    def synchroniser_modal_analysis(
        self: "CastSelf",
    ) -> "_5024.SynchroniserModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _5024,
        )

        return self.__parent__._cast(_5024.SynchroniserModalAnalysis)

    @property
    def torque_converter_modal_analysis(
        self: "CastSelf",
    ) -> "_5028.TorqueConverterModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _5028,
        )

        return self.__parent__._cast(_5028.TorqueConverterModalAnalysis)

    @property
    def worm_gear_set_modal_analysis(
        self: "CastSelf",
    ) -> "_5038.WormGearSetModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _5038,
        )

        return self.__parent__._cast(_5038.WormGearSetModalAnalysis)

    @property
    def zerol_bevel_gear_set_modal_analysis(
        self: "CastSelf",
    ) -> "_5041.ZerolBevelGearSetModalAnalysis":
        from mastapy._private.system_model.analyses_and_results.modal_analyses import (
            _5041,
        )

        return self.__parent__._cast(_5041.ZerolBevelGearSetModalAnalysis)

    @property
    def abstract_assembly_modal_analysis(
        self: "CastSelf",
    ) -> "AbstractAssemblyModalAnalysis":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class AbstractAssemblyModalAnalysis(_4988.PartModalAnalysis):
    """AbstractAssemblyModalAnalysis

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _ABSTRACT_ASSEMBLY_MODAL_ANALYSIS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def component_design(self: "Self") -> "_2704.AbstractAssembly":
        """mastapy.system_model.part_model.AbstractAssembly

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ComponentDesign")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def assembly_design(self: "Self") -> "_2704.AbstractAssembly":
        """mastapy.system_model.part_model.AbstractAssembly

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "AssemblyDesign")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def gear_meshes(self: "Self") -> "List[_4958.GearMeshModalAnalysis]":
        """List[mastapy.system_model.analyses_and_results.modal_analyses.GearMeshModalAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "GearMeshes")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def rigidly_connected_groups(self: "Self") -> "List[_4920.ComponentModalAnalysis]":
        """List[mastapy.system_model.analyses_and_results.modal_analyses.ComponentModalAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "RigidlyConnectedGroups")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def system_deflection_results(
        self: "Self",
    ) -> "_2978.AbstractAssemblySystemDeflection":
        """mastapy.system_model.analyses_and_results.system_deflections.AbstractAssemblySystemDeflection

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "SystemDeflectionResults")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: "Self") -> "_Cast_AbstractAssemblyModalAnalysis":
        """Cast to another type.

        Returns:
            _Cast_AbstractAssemblyModalAnalysis
        """
        return _Cast_AbstractAssemblyModalAnalysis(self)



"""ProcessSimulationInput"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_method_call,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private import _0
from mastapy._private._internal import constructor, conversion, utility

_PROCESS_SIMULATION_INPUT = python_net_import(
    "SMT.MastaAPI.Gears.Manufacturing.Cylindrical.HobbingProcessSimulationNew",
    "ProcessSimulationInput",
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private._internal.typing import PathLike

    from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new import (
        _785,
        _789,
        _790,
        _791,
        _798,
        _816,
        _825,
    )
    from mastapy._private.math_utility import _1751

    Self = TypeVar("Self", bound="ProcessSimulationInput")
    CastSelf = TypeVar(
        "CastSelf", bound="ProcessSimulationInput._Cast_ProcessSimulationInput"
    )


__docformat__ = "restructuredtext en"
__all__ = ("ProcessSimulationInput",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ProcessSimulationInput:
    """Special nested class for casting ProcessSimulationInput to subclasses."""

    __parent__: "ProcessSimulationInput"

    @property
    def hobbing_process_simulation_input(
        self: "CastSelf",
    ) -> "_798.HobbingProcessSimulationInput":
        from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new import (
            _798,
        )

        return self.__parent__._cast(_798.HobbingProcessSimulationInput)

    @property
    def worm_grinding_process_simulation_input(
        self: "CastSelf",
    ) -> "_825.WormGrindingProcessSimulationInput":
        from mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new import (
            _825,
        )

        return self.__parent__._cast(_825.WormGrindingProcessSimulationInput)

    @property
    def process_simulation_input(self: "CastSelf") -> "ProcessSimulationInput":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class ProcessSimulationInput(_0.APIBase):
    """ProcessSimulationInput

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _PROCESS_SIMULATION_INPUT

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def analysis_setting(self: "Self") -> "_785.AnalysisMethod":
        """mastapy.gears.manufacturing.cylindrical.hobbing_process_simulation_new.AnalysisMethod"""
        temp = pythonnet_property_get(self.wrapped, "AnalysisSetting")

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp,
            "SMT.MastaAPI.Gears.Manufacturing.Cylindrical.HobbingProcessSimulationNew.AnalysisMethod",
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._785",
            "AnalysisMethod",
        )(value)

    @analysis_setting.setter
    @exception_bridge
    @enforce_parameter_types
    def analysis_setting(self: "Self", value: "_785.AnalysisMethod") -> None:
        value = conversion.mp_to_pn_enum(
            value,
            "SMT.MastaAPI.Gears.Manufacturing.Cylindrical.HobbingProcessSimulationNew.AnalysisMethod",
        )
        pythonnet_property_set(self.wrapped, "AnalysisSetting", value)

    @property
    @exception_bridge
    def centre_distance_offset(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "CentreDistanceOffset")

        if temp is None:
            return 0.0

        return temp

    @centre_distance_offset.setter
    @exception_bridge
    @enforce_parameter_types
    def centre_distance_offset(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "CentreDistanceOffset",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def centre_distance_offset_specification_method(
        self: "Self",
    ) -> "_789.CentreDistanceOffsetMethod":
        """mastapy.gears.manufacturing.cylindrical.hobbing_process_simulation_new.CentreDistanceOffsetMethod"""
        temp = pythonnet_property_get(
            self.wrapped, "CentreDistanceOffsetSpecificationMethod"
        )

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp,
            "SMT.MastaAPI.Gears.Manufacturing.Cylindrical.HobbingProcessSimulationNew.CentreDistanceOffsetMethod",
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.gears.manufacturing.cylindrical.hobbing_process_simulation_new._789",
            "CentreDistanceOffsetMethod",
        )(value)

    @centre_distance_offset_specification_method.setter
    @exception_bridge
    @enforce_parameter_types
    def centre_distance_offset_specification_method(
        self: "Self", value: "_789.CentreDistanceOffsetMethod"
    ) -> None:
        value = conversion.mp_to_pn_enum(
            value,
            "SMT.MastaAPI.Gears.Manufacturing.Cylindrical.HobbingProcessSimulationNew.CentreDistanceOffsetMethod",
        )
        pythonnet_property_set(
            self.wrapped, "CentreDistanceOffsetSpecificationMethod", value
        )

    @property
    @exception_bridge
    def feed(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "Feed")

        if temp is None:
            return 0.0

        return temp

    @feed.setter
    @exception_bridge
    @enforce_parameter_types
    def feed(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "Feed", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def gear_design_lead_crown_modification(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "GearDesignLeadCrownModification")

        if temp is None:
            return 0.0

        return temp

    @gear_design_lead_crown_modification.setter
    @exception_bridge
    @enforce_parameter_types
    def gear_design_lead_crown_modification(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "GearDesignLeadCrownModification",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def gear_designed_lead_crown_length(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "GearDesignedLeadCrownLength")

        if temp is None:
            return 0.0

        return temp

    @gear_designed_lead_crown_length.setter
    @exception_bridge
    @enforce_parameter_types
    def gear_designed_lead_crown_length(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "GearDesignedLeadCrownLength",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def shaft_angle_offset(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "ShaftAngleOffset")

        if temp is None:
            return 0.0

        return temp

    @shaft_angle_offset.setter
    @exception_bridge
    @enforce_parameter_types
    def shaft_angle_offset(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "ShaftAngleOffset", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def start_height_above_the_gear_center(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "StartHeightAboveTheGearCenter")

        if temp is None:
            return 0.0

        return temp

    @start_height_above_the_gear_center.setter
    @exception_bridge
    @enforce_parameter_types
    def start_height_above_the_gear_center(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "StartHeightAboveTheGearCenter",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def tooth_index(self: "Self") -> "int":
        """int"""
        temp = pythonnet_property_get(self.wrapped, "ToothIndex")

        if temp is None:
            return 0

        return temp

    @tooth_index.setter
    @exception_bridge
    @enforce_parameter_types
    def tooth_index(self: "Self", value: "int") -> None:
        pythonnet_property_set(
            self.wrapped, "ToothIndex", int(value) if value is not None else 0
        )

    @property
    @exception_bridge
    def user_specified_center_distance_offset_relative_to_cutter_height(
        self: "Self",
    ) -> "_1751.Vector2DListAccessor":
        """mastapy.math_utility.Vector2DListAccessor"""
        temp = pythonnet_property_get(
            self.wrapped, "UserSpecifiedCenterDistanceOffsetRelativeToCutterHeight"
        )

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @user_specified_center_distance_offset_relative_to_cutter_height.setter
    @exception_bridge
    @enforce_parameter_types
    def user_specified_center_distance_offset_relative_to_cutter_height(
        self: "Self", value: "_1751.Vector2DListAccessor"
    ) -> None:
        pythonnet_property_set(
            self.wrapped,
            "UserSpecifiedCenterDistanceOffsetRelativeToCutterHeight",
            value.wrapped,
        )

    @property
    @exception_bridge
    def cutter_head_slide_error(self: "Self") -> "_790.CutterHeadSlideError":
        """mastapy.gears.manufacturing.cylindrical.hobbing_process_simulation_new.CutterHeadSlideError

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "CutterHeadSlideError")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def cutter_mounting_error(self: "Self") -> "_816.RackMountingError":
        """mastapy.gears.manufacturing.cylindrical.hobbing_process_simulation_new.RackMountingError

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "CutterMountingError")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def gear_mounting_error(self: "Self") -> "_791.GearMountingError":
        """mastapy.gears.manufacturing.cylindrical.hobbing_process_simulation_new.GearMountingError

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "GearMountingError")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def report_names(self: "Self") -> "List[str]":
        """List[str]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ReportNames")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, str)

        if value is None:
            return None

        return value

    @exception_bridge
    @enforce_parameter_types
    def output_default_report_to(self: "Self", file_path: "PathLike") -> None:
        """Method does not return.

        Args:
            file_path (PathLike)
        """
        file_path = str(file_path)
        pythonnet_method_call(self.wrapped, "OutputDefaultReportTo", file_path)

    @exception_bridge
    def get_default_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = pythonnet_method_call(
            self.wrapped, "GetDefaultReportWithEncodedImages"
        )
        return method_result

    @exception_bridge
    @enforce_parameter_types
    def output_active_report_to(self: "Self", file_path: "PathLike") -> None:
        """Method does not return.

        Args:
            file_path (PathLike)
        """
        file_path = str(file_path)
        pythonnet_method_call(self.wrapped, "OutputActiveReportTo", file_path)

    @exception_bridge
    @enforce_parameter_types
    def output_active_report_as_text_to(self: "Self", file_path: "PathLike") -> None:
        """Method does not return.

        Args:
            file_path (PathLike)
        """
        file_path = str(file_path)
        pythonnet_method_call(self.wrapped, "OutputActiveReportAsTextTo", file_path)

    @exception_bridge
    def get_active_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = pythonnet_method_call(
            self.wrapped, "GetActiveReportWithEncodedImages"
        )
        return method_result

    @exception_bridge
    @enforce_parameter_types
    def output_named_report_to(
        self: "Self", report_name: "str", file_path: "PathLike"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (PathLike)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped,
            "OutputNamedReportTo",
            report_name if report_name else "",
            file_path,
        )

    @exception_bridge
    @enforce_parameter_types
    def output_named_report_as_masta_report(
        self: "Self", report_name: "str", file_path: "PathLike"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (PathLike)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped,
            "OutputNamedReportAsMastaReport",
            report_name if report_name else "",
            file_path,
        )

    @exception_bridge
    @enforce_parameter_types
    def output_named_report_as_text_to(
        self: "Self", report_name: "str", file_path: "PathLike"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (PathLike)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped,
            "OutputNamedReportAsTextTo",
            report_name if report_name else "",
            file_path,
        )

    @exception_bridge
    @enforce_parameter_types
    def get_named_report_with_encoded_images(self: "Self", report_name: "str") -> "str":
        """str

        Args:
            report_name (str)
        """
        report_name = str(report_name)
        method_result = pythonnet_method_call(
            self.wrapped,
            "GetNamedReportWithEncodedImages",
            report_name if report_name else "",
        )
        return method_result

    @property
    def cast_to(self: "Self") -> "_Cast_ProcessSimulationInput":
        """Cast to another type.

        Returns:
            _Cast_ProcessSimulationInput
        """
        return _Cast_ProcessSimulationInput(self)



"""HarmonicAnalysisViewable"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.list_with_selected_item import (
    promote_to_list_with_selected_item,
)
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_method_call,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.sentinels import ListWithSelectedItem_None
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private._internal import (
    constructor,
    conversion,
    enum_with_selected_value_runtime,
    utility,
)
from mastapy._private._internal.implicit import (
    enum_with_selected_value,
    list_with_selected_item,
)
from mastapy._private.math_utility import _1746
from mastapy._private.system_model.analyses_and_results.harmonic_analyses import (
    _6022,
    _6116,
)
from mastapy._private.system_model.analyses_and_results.modal_analyses import _4950
from mastapy._private.system_model.analyses_and_results.system_deflections import _3052
from mastapy._private.system_model.drawing import _2508
from mastapy._private.system_model.drawing.options import _2522

_HARMONIC_ANALYSIS_VIEWABLE = python_net_import(
    "SMT.MastaAPI.SystemModel.Drawing", "HarmonicAnalysisViewable"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results.dynamic_analyses import (
        _6696,
    )
    from mastapy._private.system_model.drawing import _2513

    Self = TypeVar("Self", bound="HarmonicAnalysisViewable")
    CastSelf = TypeVar(
        "CastSelf", bound="HarmonicAnalysisViewable._Cast_HarmonicAnalysisViewable"
    )


__docformat__ = "restructuredtext en"
__all__ = ("HarmonicAnalysisViewable",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_HarmonicAnalysisViewable:
    """Special nested class for casting HarmonicAnalysisViewable to subclasses."""

    __parent__: "HarmonicAnalysisViewable"

    @property
    def dynamic_analysis_viewable(self: "CastSelf") -> "_2508.DynamicAnalysisViewable":
        return self.__parent__._cast(_2508.DynamicAnalysisViewable)

    @property
    def part_analysis_case_with_contour_viewable(
        self: "CastSelf",
    ) -> "_2513.PartAnalysisCaseWithContourViewable":
        from mastapy._private.system_model.drawing import _2513

        return self.__parent__._cast(_2513.PartAnalysisCaseWithContourViewable)

    @property
    def harmonic_analysis_viewable(self: "CastSelf") -> "HarmonicAnalysisViewable":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class HarmonicAnalysisViewable(_2508.DynamicAnalysisViewable):
    """HarmonicAnalysisViewable

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _HARMONIC_ANALYSIS_VIEWABLE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def animate_acoustic_results(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "AnimateAcousticResults")

        if temp is None:
            return False

        return temp

    @animate_acoustic_results.setter
    @exception_bridge
    @enforce_parameter_types
    def animate_acoustic_results(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "AnimateAcousticResults",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def draw_boundary_surface_pressure_result(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "DrawBoundarySurfacePressureResult")

        if temp is None:
            return False

        return temp

    @draw_boundary_surface_pressure_result.setter
    @exception_bridge
    @enforce_parameter_types
    def draw_boundary_surface_pressure_result(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "DrawBoundarySurfacePressureResult",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def draw_pressure_at_reflecting_plane(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "DrawPressureAtReflectingPlane")

        if temp is None:
            return False

        return temp

    @draw_pressure_at_reflecting_plane.setter
    @exception_bridge
    @enforce_parameter_types
    def draw_pressure_at_reflecting_plane(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "DrawPressureAtReflectingPlane",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def excitation(
        self: "Self",
    ) -> (
        "list_with_selected_item.ListWithSelectedItem_AbstractPeriodicExcitationDetail"
    ):
        """ListWithSelectedItem[mastapy.system_model.analyses_and_results.harmonic_analyses.AbstractPeriodicExcitationDetail]"""
        temp = pythonnet_property_get(self.wrapped, "Excitation")

        if temp is None:
            return None

        selected_value = temp.SelectedValue

        if selected_value is None:
            return ListWithSelectedItem_None(temp)

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_AbstractPeriodicExcitationDetail",
        )(temp)

    @excitation.setter
    @exception_bridge
    @enforce_parameter_types
    def excitation(
        self: "Self", value: "_6022.AbstractPeriodicExcitationDetail"
    ) -> None:
        generic_type = list_with_selected_item.ListWithSelectedItem_AbstractPeriodicExcitationDetail.implicit_type()
        value = promote_to_list_with_selected_item(value)
        value = conversion.mp_to_pn_smt_list_with_selected_item(
            self, value, generic_type
        )
        pythonnet_property_set(self.wrapped, "Excitation", value)

    @property
    @exception_bridge
    def frequency(
        self: "Self",
    ) -> "list_with_selected_item.ListWithSelectedItem_NamedTuple1_float":
        """ListWithSelectedItem[mastapy.utility.generics.NamedTuple1[float]]"""
        temp = pythonnet_property_get(self.wrapped, "Frequency")

        if temp is None:
            return None

        selected_value = temp.SelectedValue

        if selected_value is None:
            return ListWithSelectedItem_None(temp)

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_NamedTuple1_float",
        )(temp)

    @frequency.setter
    @exception_bridge
    @enforce_parameter_types
    def frequency(self: "Self", value: "float") -> None:
        generic_type = list_with_selected_item.ListWithSelectedItem_NamedTuple1_float.implicit_type()
        value = promote_to_list_with_selected_item(value)
        value = conversion.mp_to_pn_smt_list_with_selected_item(
            self, value, generic_type
        )
        pythonnet_property_set(self.wrapped, "Frequency", value)

    @property
    @exception_bridge
    def harmonic(self: "Self") -> "list_with_selected_item.ListWithSelectedItem_int":
        """ListWithSelectedItem[int]"""
        temp = pythonnet_property_get(self.wrapped, "Harmonic")

        if temp is None:
            return 0

        selected_value = temp.SelectedValue

        if selected_value is None:
            return ListWithSelectedItem_None(temp)

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_int",
        )(temp)

    @harmonic.setter
    @exception_bridge
    @enforce_parameter_types
    def harmonic(self: "Self", value: "int") -> None:
        generic_type = list_with_selected_item.ListWithSelectedItem_int.implicit_type()
        value = promote_to_list_with_selected_item(value)
        value = conversion.mp_to_pn_smt_list_with_selected_item(
            self, value, generic_type
        )
        pythonnet_property_set(self.wrapped, "Harmonic", value)

    @property
    @exception_bridge
    def harmonic_analysis_with_varying_stiffness_step(
        self: "Self",
    ) -> "list_with_selected_item.ListWithSelectedItem_HarmonicAnalysisWithVaryingStiffnessStaticLoadCase":
        """ListWithSelectedItem[mastapy.system_model.analyses_and_results.harmonic_analyses.HarmonicAnalysisWithVaryingStiffnessStaticLoadCase]"""
        temp = pythonnet_property_get(
            self.wrapped, "HarmonicAnalysisWithVaryingStiffnessStep"
        )

        if temp is None:
            return None

        selected_value = temp.SelectedValue

        if selected_value is None:
            return ListWithSelectedItem_None(temp)

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_HarmonicAnalysisWithVaryingStiffnessStaticLoadCase",
        )(temp)

    @harmonic_analysis_with_varying_stiffness_step.setter
    @exception_bridge
    @enforce_parameter_types
    def harmonic_analysis_with_varying_stiffness_step(
        self: "Self", value: "_6116.HarmonicAnalysisWithVaryingStiffnessStaticLoadCase"
    ) -> None:
        generic_type = list_with_selected_item.ListWithSelectedItem_HarmonicAnalysisWithVaryingStiffnessStaticLoadCase.implicit_type()
        value = promote_to_list_with_selected_item(value)
        value = conversion.mp_to_pn_smt_list_with_selected_item(
            self, value, generic_type
        )
        pythonnet_property_set(
            self.wrapped, "HarmonicAnalysisWithVaryingStiffnessStep", value
        )

    @property
    @exception_bridge
    def order(
        self: "Self",
    ) -> "list_with_selected_item.ListWithSelectedItem_RoundedOrder":
        """ListWithSelectedItem[mastapy.math_utility.RoundedOrder]"""
        temp = pythonnet_property_get(self.wrapped, "Order")

        if temp is None:
            return None

        selected_value = temp.SelectedValue

        if selected_value is None:
            return ListWithSelectedItem_None(temp)

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_RoundedOrder",
        )(temp)

    @order.setter
    @exception_bridge
    @enforce_parameter_types
    def order(self: "Self", value: "_1746.RoundedOrder") -> None:
        generic_type = (
            list_with_selected_item.ListWithSelectedItem_RoundedOrder.implicit_type()
        )
        value = promote_to_list_with_selected_item(value)
        value = conversion.mp_to_pn_smt_list_with_selected_item(
            self, value, generic_type
        )
        pythonnet_property_set(self.wrapped, "Order", value)

    @property
    @exception_bridge
    def reference_power_load_speed(
        self: "Self",
    ) -> "list_with_selected_item.ListWithSelectedItem_NamedTuple1_float":
        """ListWithSelectedItem[mastapy.utility.generics.NamedTuple1[float]]"""
        temp = pythonnet_property_get(self.wrapped, "ReferencePowerLoadSpeed")

        if temp is None:
            return None

        selected_value = temp.SelectedValue

        if selected_value is None:
            return ListWithSelectedItem_None(temp)

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_NamedTuple1_float",
        )(temp)

    @reference_power_load_speed.setter
    @exception_bridge
    @enforce_parameter_types
    def reference_power_load_speed(self: "Self", value: "float") -> None:
        generic_type = list_with_selected_item.ListWithSelectedItem_NamedTuple1_float.implicit_type()
        value = promote_to_list_with_selected_item(value)
        value = conversion.mp_to_pn_smt_list_with_selected_item(
            self, value, generic_type
        )
        pythonnet_property_set(self.wrapped, "ReferencePowerLoadSpeed", value)

    @property
    @exception_bridge
    def sound_response_type(
        self: "Self",
    ) -> "enum_with_selected_value.EnumWithSelectedValue_DynamicsResponseType":
        """EnumWithSelectedValue[mastapy.system_model.analyses_and_results.modal_analyses.DynamicsResponseType]"""
        temp = pythonnet_property_get(self.wrapped, "SoundResponseType")

        if temp is None:
            return None

        value = enum_with_selected_value.EnumWithSelectedValue_DynamicsResponseType.wrapped_type()
        return enum_with_selected_value_runtime.create(temp, value)

    @sound_response_type.setter
    @exception_bridge
    @enforce_parameter_types
    def sound_response_type(self: "Self", value: "_4950.DynamicsResponseType") -> None:
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = enum_with_selected_value.EnumWithSelectedValue_DynamicsResponseType.implicit_type()
        value = conversion.mp_to_pn_enum(value, enclosed_type)
        value = wrapper_type[enclosed_type](value)
        pythonnet_property_set(self.wrapped, "SoundResponseType", value)

    @property
    @exception_bridge
    def uncoupled_mesh(
        self: "Self",
    ) -> "list_with_selected_item.ListWithSelectedItem_GearMeshSystemDeflection":
        """ListWithSelectedItem[mastapy.system_model.analyses_and_results.system_deflections.GearMeshSystemDeflection]"""
        temp = pythonnet_property_get(self.wrapped, "UncoupledMesh")

        if temp is None:
            return None

        selected_value = temp.SelectedValue

        if selected_value is None:
            return ListWithSelectedItem_None(temp)

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_GearMeshSystemDeflection",
        )(temp)

    @uncoupled_mesh.setter
    @exception_bridge
    @enforce_parameter_types
    def uncoupled_mesh(self: "Self", value: "_3052.GearMeshSystemDeflection") -> None:
        generic_type = list_with_selected_item.ListWithSelectedItem_GearMeshSystemDeflection.implicit_type()
        value = promote_to_list_with_selected_item(value)
        value = conversion.mp_to_pn_smt_list_with_selected_item(
            self, value, generic_type
        )
        pythonnet_property_set(self.wrapped, "UncoupledMesh", value)

    @property
    @exception_bridge
    def view_type(
        self: "Self",
    ) -> "enum_with_selected_value.EnumWithSelectedValue_ExcitationAnalysisViewOption":
        """EnumWithSelectedValue[mastapy.system_model.drawing.options.ExcitationAnalysisViewOption]"""
        temp = pythonnet_property_get(self.wrapped, "ViewType")

        if temp is None:
            return None

        value = enum_with_selected_value.EnumWithSelectedValue_ExcitationAnalysisViewOption.wrapped_type()
        return enum_with_selected_value_runtime.create(temp, value)

    @view_type.setter
    @exception_bridge
    @enforce_parameter_types
    def view_type(self: "Self", value: "_2522.ExcitationAnalysisViewOption") -> None:
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = enum_with_selected_value.EnumWithSelectedValue_ExcitationAnalysisViewOption.implicit_type()
        value = conversion.mp_to_pn_enum(value, enclosed_type)
        value = wrapper_type[enclosed_type](value)
        pythonnet_property_set(self.wrapped, "ViewType", value)

    @property
    @exception_bridge
    def dynamic_analysis_draw_style(self: "Self") -> "_6696.DynamicAnalysisDrawStyle":
        """mastapy.system_model.analyses_and_results.dynamic_analyses.DynamicAnalysisDrawStyle

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "DynamicAnalysisDrawStyle")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @exception_bridge
    def calculate_result_for_selected_surfaces(self: "Self") -> None:
        """Method does not return."""
        pythonnet_method_call(self.wrapped, "CalculateResultForSelectedSurfaces")

    @property
    def cast_to(self: "Self") -> "_Cast_HarmonicAnalysisViewable":
        """Cast to another type.

        Returns:
            _Cast_HarmonicAnalysisViewable
        """
        return _Cast_HarmonicAnalysisViewable(self)



"""KlingelnbergCycloPalloidHypoidGearMeshCompoundHarmonicAnalysis"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound import (
    _6306,
)

_KLINGELNBERG_CYCLO_PALLOID_HYPOID_GEAR_MESH_COMPOUND_HARMONIC_ANALYSIS = (
    python_net_import(
        "SMT.MastaAPI.SystemModel.AnalysesAndResults.HarmonicAnalyses.Compound",
        "KlingelnbergCycloPalloidHypoidGearMeshCompoundHarmonicAnalysis",
    )
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results import _2944
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7937,
        _7941,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses import (
        _6125,
    )
    from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound import (
        _6272,
        _6274,
        _6298,
        _6304,
    )
    from mastapy._private.system_model.connections_and_sockets.gears import _2579

    Self = TypeVar(
        "Self", bound="KlingelnbergCycloPalloidHypoidGearMeshCompoundHarmonicAnalysis"
    )
    CastSelf = TypeVar(
        "CastSelf",
        bound="KlingelnbergCycloPalloidHypoidGearMeshCompoundHarmonicAnalysis._Cast_KlingelnbergCycloPalloidHypoidGearMeshCompoundHarmonicAnalysis",
    )


__docformat__ = "restructuredtext en"
__all__ = ("KlingelnbergCycloPalloidHypoidGearMeshCompoundHarmonicAnalysis",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_KlingelnbergCycloPalloidHypoidGearMeshCompoundHarmonicAnalysis:
    """Special nested class for casting KlingelnbergCycloPalloidHypoidGearMeshCompoundHarmonicAnalysis to subclasses."""

    __parent__: "KlingelnbergCycloPalloidHypoidGearMeshCompoundHarmonicAnalysis"

    @property
    def klingelnberg_cyclo_palloid_conical_gear_mesh_compound_harmonic_analysis(
        self: "CastSelf",
    ) -> "_6306.KlingelnbergCycloPalloidConicalGearMeshCompoundHarmonicAnalysis":
        return self.__parent__._cast(
            _6306.KlingelnbergCycloPalloidConicalGearMeshCompoundHarmonicAnalysis
        )

    @property
    def conical_gear_mesh_compound_harmonic_analysis(
        self: "CastSelf",
    ) -> "_6272.ConicalGearMeshCompoundHarmonicAnalysis":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound import (
            _6272,
        )

        return self.__parent__._cast(_6272.ConicalGearMeshCompoundHarmonicAnalysis)

    @property
    def gear_mesh_compound_harmonic_analysis(
        self: "CastSelf",
    ) -> "_6298.GearMeshCompoundHarmonicAnalysis":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound import (
            _6298,
        )

        return self.__parent__._cast(_6298.GearMeshCompoundHarmonicAnalysis)

    @property
    def inter_mountable_component_connection_compound_harmonic_analysis(
        self: "CastSelf",
    ) -> "_6304.InterMountableComponentConnectionCompoundHarmonicAnalysis":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound import (
            _6304,
        )

        return self.__parent__._cast(
            _6304.InterMountableComponentConnectionCompoundHarmonicAnalysis
        )

    @property
    def connection_compound_harmonic_analysis(
        self: "CastSelf",
    ) -> "_6274.ConnectionCompoundHarmonicAnalysis":
        from mastapy._private.system_model.analyses_and_results.harmonic_analyses.compound import (
            _6274,
        )

        return self.__parent__._cast(_6274.ConnectionCompoundHarmonicAnalysis)

    @property
    def connection_compound_analysis(
        self: "CastSelf",
    ) -> "_7937.ConnectionCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7937,
        )

        return self.__parent__._cast(_7937.ConnectionCompoundAnalysis)

    @property
    def design_entity_compound_analysis(
        self: "CastSelf",
    ) -> "_7941.DesignEntityCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7941,
        )

        return self.__parent__._cast(_7941.DesignEntityCompoundAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2944.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2944

        return self.__parent__._cast(_2944.DesignEntityAnalysis)

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_mesh_compound_harmonic_analysis(
        self: "CastSelf",
    ) -> "KlingelnbergCycloPalloidHypoidGearMeshCompoundHarmonicAnalysis":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class KlingelnbergCycloPalloidHypoidGearMeshCompoundHarmonicAnalysis(
    _6306.KlingelnbergCycloPalloidConicalGearMeshCompoundHarmonicAnalysis
):
    """KlingelnbergCycloPalloidHypoidGearMeshCompoundHarmonicAnalysis

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = (
        _KLINGELNBERG_CYCLO_PALLOID_HYPOID_GEAR_MESH_COMPOUND_HARMONIC_ANALYSIS
    )

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def component_design(
        self: "Self",
    ) -> "_2579.KlingelnbergCycloPalloidHypoidGearMesh":
        """mastapy.system_model.connections_and_sockets.gears.KlingelnbergCycloPalloidHypoidGearMesh

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ComponentDesign")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def connection_design(
        self: "Self",
    ) -> "_2579.KlingelnbergCycloPalloidHypoidGearMesh":
        """mastapy.system_model.connections_and_sockets.gears.KlingelnbergCycloPalloidHypoidGearMesh

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ConnectionDesign")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def connection_analysis_cases_ready(
        self: "Self",
    ) -> "List[_6125.KlingelnbergCycloPalloidHypoidGearMeshHarmonicAnalysis]":
        """List[mastapy.system_model.analyses_and_results.harmonic_analyses.KlingelnbergCycloPalloidHypoidGearMeshHarmonicAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ConnectionAnalysisCasesReady")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def connection_analysis_cases(
        self: "Self",
    ) -> "List[_6125.KlingelnbergCycloPalloidHypoidGearMeshHarmonicAnalysis]":
        """List[mastapy.system_model.analyses_and_results.harmonic_analyses.KlingelnbergCycloPalloidHypoidGearMeshHarmonicAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ConnectionAnalysisCases")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(
        self: "Self",
    ) -> "_Cast_KlingelnbergCycloPalloidHypoidGearMeshCompoundHarmonicAnalysis":
        """Cast to another type.

        Returns:
            _Cast_KlingelnbergCycloPalloidHypoidGearMeshCompoundHarmonicAnalysis
        """
        return _Cast_KlingelnbergCycloPalloidHypoidGearMeshCompoundHarmonicAnalysis(
            self
        )



"""WoundFieldSynchronousRotor"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.overridable_constructor import _unpack_overridable
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private._internal import constructor, conversion, utility
from mastapy._private._internal.implicit import overridable
from mastapy._private.electric_machines import _1436

_WOUND_FIELD_SYNCHRONOUS_ROTOR = python_net_import(
    "SMT.MastaAPI.ElectricMachines", "WoundFieldSynchronousRotor"
)

if TYPE_CHECKING:
    from typing import Any, List, Tuple, Type, TypeVar, Union

    from mastapy._private.electric_machines import _1425, _1426, _1452, _1457

    Self = TypeVar("Self", bound="WoundFieldSynchronousRotor")
    CastSelf = TypeVar(
        "CastSelf", bound="WoundFieldSynchronousRotor._Cast_WoundFieldSynchronousRotor"
    )


__docformat__ = "restructuredtext en"
__all__ = ("WoundFieldSynchronousRotor",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_WoundFieldSynchronousRotor:
    """Special nested class for casting WoundFieldSynchronousRotor to subclasses."""

    __parent__: "WoundFieldSynchronousRotor"

    @property
    def interior_permanent_magnet_and_synchronous_reluctance_rotor(
        self: "CastSelf",
    ) -> "_1436.InteriorPermanentMagnetAndSynchronousReluctanceRotor":
        return self.__parent__._cast(
            _1436.InteriorPermanentMagnetAndSynchronousReluctanceRotor
        )

    @property
    def permanent_magnet_rotor(self: "CastSelf") -> "_1452.PermanentMagnetRotor":
        from mastapy._private.electric_machines import _1452

        return self.__parent__._cast(_1452.PermanentMagnetRotor)

    @property
    def rotor(self: "CastSelf") -> "_1457.Rotor":
        from mastapy._private.electric_machines import _1457

        return self.__parent__._cast(_1457.Rotor)

    @property
    def wound_field_synchronous_rotor(self: "CastSelf") -> "WoundFieldSynchronousRotor":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class WoundFieldSynchronousRotor(
    _1436.InteriorPermanentMagnetAndSynchronousReluctanceRotor
):
    """WoundFieldSynchronousRotor

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _WOUND_FIELD_SYNCHRONOUS_ROTOR

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def number_of_field_winding_regions(self: "Self") -> "int":
        """int"""
        temp = pythonnet_property_get(self.wrapped, "NumberOfFieldWindingRegions")

        if temp is None:
            return 0

        return temp

    @number_of_field_winding_regions.setter
    @exception_bridge
    @enforce_parameter_types
    def number_of_field_winding_regions(self: "Self", value: "int") -> None:
        pythonnet_property_set(
            self.wrapped,
            "NumberOfFieldWindingRegions",
            int(value) if value is not None else 0,
        )

    @property
    @exception_bridge
    def pole_depth(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "PoleDepth")

        if temp is None:
            return 0.0

        return temp

    @pole_depth.setter
    @exception_bridge
    @enforce_parameter_types
    def pole_depth(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "PoleDepth", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def pole_tip_depth(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "PoleTipDepth")

        if temp is None:
            return 0.0

        return temp

    @pole_tip_depth.setter
    @exception_bridge
    @enforce_parameter_types
    def pole_tip_depth(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "PoleTipDepth", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def pole_tip_radius(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(self.wrapped, "PoleTipRadius")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @pole_tip_radius.setter
    @exception_bridge
    @enforce_parameter_types
    def pole_tip_radius(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(self.wrapped, "PoleTipRadius", value)

    @property
    @exception_bridge
    def pole_tip_width(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "PoleTipWidth")

        if temp is None:
            return 0.0

        return temp

    @pole_tip_width.setter
    @exception_bridge
    @enforce_parameter_types
    def pole_tip_width(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "PoleTipWidth", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def pole_width(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "PoleWidth")

        if temp is None:
            return 0.0

        return temp

    @pole_width.setter
    @exception_bridge
    @enforce_parameter_types
    def pole_width(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "PoleWidth", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def field_winding_specification(
        self: "Self",
    ) -> "_1426.FieldWindingSpecificationBase":
        """mastapy.electric_machines.FieldWindingSpecificationBase

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "FieldWindingSpecification")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def field_winding_specifications(
        self: "Self",
    ) -> "List[_1425.FieldWindingSpecification]":
        """List[mastapy.electric_machines.FieldWindingSpecification]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "FieldWindingSpecifications")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_WoundFieldSynchronousRotor":
        """Cast to another type.

        Returns:
            _Cast_WoundFieldSynchronousRotor
        """
        return _Cast_WoundFieldSynchronousRotor(self)
